Package: BLSloadR
Type: Package
Title: Download Time Series Data from the U.S. Bureau of Labor
        Statistics
Version: 0.4.5
Authors@R: c(
    person(
    given = "Nevada Department of Employment, Training, and Rehabilitation",
    role = "cph"
    ),
    person(
      given = "David", family = "Schmidt",
      email = "deschmidt@detr.nv.gov",
      role = c("aut", "cre")
    ),
    person(
      given = "Mark", family = "Rembert",
      email = "Mark.Rembert@mass.gov",
      role = c("aut")
    )
  )
Description: These functions provide a convenient interface for downloading data from the U.S. Bureau of Labor Statistics <https://www.bls.gov>.  The functions in this package utilize flat files produced by the Bureau of Labor Statistics, which contain full series history.  These files include employment, unemployment, wages, prices, industry and occupational data at a national, state, and sub-state level, depending on the series.  Individual functions are included for those programs which have data available at the state level.  The core functions provide direct access to the Current Employment Statistics (CES) <https://www.bls.gov/ces/>, Local Area Unemployment Statistics (LAUS) <https://www.bls.gov/lau/>, Occupational Employment and Wage Statistics (OEWS) <https://www.bls.gov/oes/> and Alternative Measures of Labor Underutilization (SALT) <https://www.bls.gov/lau/stalt.htm> data produced by the Bureau of Labor Statistics.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: data.table (>= 1.16), httr (>= 1.4.7), dplyr (>= 1.1), stringr
        (>= 1.5), lubridate (>= 1.9), rvest (>= 1.0.4), readxl (>=
        1.4.5), sf (>= 1.0), tidyselect (>= 1.2), tigris (>= 2.0), zoo
        (>= 1.8), htmltools, rstudioapi
RoxygenNote: 7.3.3
Suggests: ggplot2, knitr, mapgl, rmarkdown, tidyr, gt
VignetteBuilder: knitr
URL: https://schmidtdetr.github.io/BLSloadR/
Config/Needs/website: rmarkdown
LazyData: true
NeedsCompilation: no
Packaged: 2026-04-22 16:44:19 UTC; deschmidt
Author: Nevada Department of Employment, Training, and Rehabilitation [cph],
  David Schmidt [aut, cre],
  Mark Rembert [aut]
Maintainer: David Schmidt <deschmidt@detr.nv.gov>
Repository: CRAN
Date/Publication: 2026-04-23 05:10:59 UTC
