% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_helpers.R
\name{get_bls_excel_headers}
\alias{get_bls_excel_headers}
\title{Generate headers for BLS requests to download Excel files}
\usage{
get_bls_excel_headers(refer = "https://www.bls.gov/lau/stalt-archived.htm")
}
\arguments{
\item{refer}{The URL to use in the Referer header (default: "https://www.bls.gov/lau/stalt-archived.htm")}
}
\value{
A named character vector of HTTP headers
}
\description{
Returns a named character vector of HTTP headers required for BLS API requests.
These headers mimic a standard browser to ensure compatibility with BLS servers.
This function returns a more limited set of headers used to download an Ecel file.
}
\keyword{internal}
