% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/download_helpers.R
\name{get_bls_headers}
\alias{get_bls_headers}
\title{Generate headers for BLS requests}
\usage{
get_bls_headers(host = "download.bls.gov")
}
\arguments{
\item{host}{The URL to use in the Host header (default: "download.bls.gov")}
}
\value{
A named character vector of HTTP headers
}
\description{
Returns a named character vector of HTTP headers required for BLS API requests.
These headers mimic a standard browser to ensure compatibility with BLS servers.
}
\keyword{internal}
